#!C:/perl/bin/perl -w

use strict;

use Petal;

$|=1;

$Petal::DISK_CACHE = 1;
$Petal::MEMORY_CACHE = 1;
$Petal::TAINT = 1;
$Petal::INPUT = "XML";
$Petal::OUTPUT = "XML";

my $template;

# This works...

$Petal::NS = "petal";
$template = new Petal('test_ns_attributes1.xml');

print "Processing using \$Petal::NS = '$Petal::NS'\n";
print $template->process(baz_value  => 'Replaced baz',
                         buzz_value => 'Replaced buzz'
                        );
print "\n\n";

# So does this...

$Petal::NS = "petal_temp";
$template = new Petal('test_ns_attributes2.xml');

print "Processing using \$Petal::NS = '$Petal::NS'\n";
print $template->process(baz_value  => 'Replaced baz',
                         buzz_value => 'Replaced buzz'
                        );
print "\n\n";

# Here, attribute 'baz' is not replaced.
# According to http://www.w3.org/TR/REC-xml-names/:
#
#   [1]  NSAttName ::=  PrefixedAttName
#                     | DefaultAttName
#   [2]  PrefixedAttName ::=  'xmlns:' NCName
#   [3]  DefaultAttName ::=  'xmlns'
#   [4]  NCName ::=  (Letter | '_') (NCNameChar)*
#   [5]  NCNameChar ::=  Letter | Digit | '.' | '-' | '_'
#                     | CombiningChar | Extender
#
# So petal-temp should be a valid NCName for the namespace

$Petal::NS = "petal-temp";
$template = new Petal('test_ns_attributes3.xml');

print "Processing using \$Petal::NS = '$Petal::NS'\n";
print $template->process(baz_value  => 'Replaced baz',
                         buzz_value => 'Replaced buzz'
                        );
print "\n\n";

# In a more complex case, we are using Petal to generate
# a Petal template! We need to replace Petal's default namespace
# with an alias so that the standard attributes xmlns:petal
# remain intact.

$Petal::NS = "petal_temp";
$Petal::NS_URI = "urn:pepsdesign.com:petal:temp";

$template = new Petal('test_ns_attributes4.xml');

print "Processing using \$Petal::NS = '$Petal::NS'\n";
print $template->process(baz_value => 'baz_value');
print "\n\n";

# This breaks when we change the namespace to petal-temp

$Petal::NS = "petal-temp";
$Petal::NS_URI = "urn:pepsdesign.com:petal:temp";

$template = new Petal('test_ns_attributes5.xml');

print "Processing using \$Petal::NS = '$Petal::NS'\n";
print $template->process(baz_value => 'baz_value');
print "\n\n";

# Replacing multiple attributes...

$Petal::NS = "petal_temp";
$Petal::NS_URI = "urn:pepsdesign.com:petal:temp";

$template = new Petal('test_ns_attributes6.xml');

print "Processing using \$Petal::NS = '$Petal::NS'\n";
print $template->process(baz_data  => 'baz_value',
                         buzz_data => 'buzz_value',
                         quxx_data => 'quxx_value',
                         SC        => ';'
                        );
print "\n\n";


# Replacing multiple attributes...

$Petal::NS = "petal-temp";
$Petal::NS_URI = "urn:pepsdesign.com:petal:temp";

$template = new Petal('test_ns_attributes7.xml');

print "Processing using \$Petal::NS = '$Petal::NS'\n";
print $template->process(baz_data  => 'baz_value',
                         buzz_data => 'buzz_value',
                         quxx_data => 'quxx_value',
                         SC        => ';'
                        );
print "\n\n";
